import React, { useState } from 'react'
import { Input, Form, Row, Col, Button } from 'antd'
import HttpService from '../../../services/httpService'
import { respuestas } from '../../../utilities'
import { SaveOutlined } from '@ant-design/icons'
import { useNavigate } from 'react-router-dom'


export const Formulario = ({ model = null, id, alTerminar, endPoint, url, idModelo, media }) => {
  const [form] = Form.useForm()
  const navigate = useNavigate()

  const [guardando, setGuardando] = useState(false)

  const handleFinish = async (values) => {

    try {
      setGuardando(true)

      let body = {
        ...values,
      }

      if (id) {
        body[idModelo] = id
      }

      const res = await HttpService.post(`${endPoint}/guardar`, body)
      if (respuestas(res)) {
        navigate(url)
      }
    } catch (e) {
      console.log(e)
    } finally {
      setGuardando(false)
    }

  }

  React.useEffect(() => {
    if (model || model !== null) {
      form.setFieldsValue({
        ...model,
      })
    } else {
      form.resetFields()
    }
  }, [form, model])

  return (<Form
      layout="vertical"
      form={form}
      onFinish={handleFinish}
    >
      <Row gutter={[10, 0]}>
        <Col xs={24} lg={12}>
          <Form.Item
            label="Clave"
            name="clave"
            rules={[{
              required: true,
              message: 'Por favor ingresa una clave'
            }]}
          >
            <Input/>
          </Form.Item>
        </Col>
        <Col xs={24} lg={12}>
          <Form.Item
            label="Nombre"
            name="nombre"
            rules={[{
              required: true,
              message: 'Por favor ingresa un nombre'
            }]}
          >
            <Input/>
          </Form.Item>
        </Col>
      </Row>
      <br/>
      <Row justify="end">
        <Col xs={24} lg={6}>
          <Form.Item>
            <Button
              type="primary"
              htmlType="submit"
              size="large"
              block
              icon={<SaveOutlined/>}
              loading={guardando}
            >
              Guardar
            </Button>
          </Form.Item>
        </Col>
      </Row>
    </Form>
  )

}
