import React, { useEffect, useState } from 'react'
import { Row, Col, Form, Button, Card, Avatar, Divider, Upload, message, Collapse } from 'antd'
import { UserOutlined, MailOutlined, PhoneOutlined, LockOutlined } from '@ant-design/icons'
import { InputPass, ViewLoading } from '../../components'
import { useApp, useAuth } from '../../hooks'
import HttpService from '../../services/httpService'
import { DefaultLayout } from '../../components/layouts'
import { respuestas } from '../../utilities'

const baseUrl = import.meta.env.VITE_API_URL

const Perfil = () => {

  const { user } = useAuth()
  const [form] = Form.useForm()
  const { token } = useApp()

  const [guardando, setGuardando] = useState(false)

  const [urlFoto, setUrlFoto] = useState(null)
  const [listaArchivosFotoPerfil, setListaArchivosFotoPerfil] = useState([])
  const [archivoCargando, setArchivoCargando] = useState(null)

  const onChangePicturePerfil = ({ fileList: newFileList }) => {
    let _archivo = newFileList[0]?.originFileObj
    const isImage = _archivo.type.includes('image/')

    if (!isImage) {
      message.error(`${_archivo.name} no es un archivo de Imagen`)
      return
    }

    subirImagenPerfil(newFileList)
  }

  const subirImagenPerfil = async (file, idDocumento) => {
    try {
      setArchivoCargando(true)

      let _archivo = file[0]?.originFileObj

      if (!_archivo) {
        message.info({
          content: 'Debes de seleccionarun archivo',
          style: { marginTop: '20vh' },
        })
        return
      }

      const form = new FormData()
      form.append('archivo', _archivo)
      form.append('idUsuario', user?.id)

      const response = await fetch(baseUrl + '/v1/perfil/cambiar-foto-perfil', {
        method: 'POST',
        headers: {
          Authorization: `Bearer ${token}`,
        },
        body: form,
      })

      const data = await response.json()
      setUrlFoto(data?.resultado[0])

      response.mensaje = data.mensaje
      respuestas(response)

    } catch (error) {
      console.log('error al cargar archivo: ', error)
    } finally {
      setArchivoCargando(false)

    }
  }

  const items = [
    {
      key: '1', label: 'Cambiar la contraseña', children: <>
        <p
          style={{
            color: '#777',
            marginBottom: '20px',
            marginTop: '-10px',
          }}
        >
          Si no desea cambiar la contraseña, deje los campos en blanco.
        </p>
        <Row gutter={[16, 16]}>
          <Col
            xs={{ span: 24 }}
            sm={{ span: 24 }}
            md={{ span: 24 }}
            lg={{ span: 24 }}
          >
            <InputPass
              label="Confirmar Contraseña"
              name="clave"
            />
          </Col>
          <Col
            xs={{ span: 24 }}
            sm={{ span: 24 }}
            md={{ span: 24 }}
            lg={{ span: 24 }}
          >
            <InputPass
              label="Contraseña"
              name="clave1"
            />
          </Col>
          <Col
            xs={{ span: 24 }}
            sm={{ span: 24 }}
            md={{ span: 24 }}
            lg={{ span: 24 }}
          >
            <Form.Item>
              <Button type="primary" htmlType="submit" loading={guardando}>
                Guardar
              </Button>
            </Form.Item>
          </Col>
        </Row>
      </>
    },
  ]

  const onFinish = async (values) => {
    try {
      setGuardando(true)

      let body = {
        ...values,
        idUsuario: user.id
      }

      const resp = await HttpService.post('usuario/cambiar-clave', body)

      if (respuestas(resp)) {
        form.resetFields()
      }
    } catch (error) {
      console.log('error en Perfil.js: ', error)
    } finally {
      setGuardando(false)
    }
  }

  useEffect(() => {
    if (!user) return

    form.setFieldsValue({
      nombre: user.nombre,
      correo: user.correo,
    })

    setUrlFoto(user?.foto)

  }, [form, user])

  if (!user) return <ViewLoading/>

  return (
    <DefaultLayout>
      <Form onFinish={onFinish} form={form} layout="vertical" name="form">
        <Row gutter={10} justify="center">
          <Col
            xs={{ span: 24 }}
            sm={{ span: 24 }}
            md={{ span: 12 }}
            lg={{ span: 12 }}
          >
            <Card>
              <div style={{ display: 'flex', flexDirection: 'column', alignItems: 'center' }}>
                <Col span={24} md={6}>
                  <Form.Item
                    label={'Elegir foto de Perfil:'}
                  >
                    <Upload
                      beforeUpload={() => false}
                      multiple={true}
                      listType="picture-card"
                      fileList={listaArchivosFotoPerfil}
                      loading={archivoCargando}
                      onChange={onChangePicturePerfil}
                      onRemove={() => {
                        setListaArchivosFotoPerfil([])
                        setUrlFoto(null)
                      }}
                    >
                      <Avatar size={100} icon={
                        <UserOutlined/>} src={urlFoto}/>
                    </Upload>
                  </Form.Item>
                </Col>
                <div /* style={{ paddingLeft: '20px' }} */>
                  <h2>{user.nombre}</h2>
                </div>
              </div>
            </Card>
          </Col>
        </Row>
        <br/>
        <Row gutter={10} justify="center">
          <Col
            xs={{ span: 24 }}
            sm={{ span: 24 }}
            md={{ span: 12 }}
            lg={{ span: 12 }}
          >
            <Card>
              <div style={{ display: 'flex', alignItems: 'center' }}>
                <Avatar size={50} icon={<UserOutlined/>}/>
                <div style={{ marginLeft: '10px' }}>
                <span>
                  Usuario: {user?.usuario} - <span style={{ color: 'blue' }}>{user?.nombre}</span>
                </span>
                </div>
              </div>
              <Divider/>
              <div style={{ display: 'flex', alignItems: 'center' }}>
                <Avatar size={50} icon={<MailOutlined/>}/>
                <div style={{ marginLeft: '10px' }}>
                <span>
                  Correo: {user?.correo}
                </span>
                </div>
              </div>
              <Divider/>
              <div style={{ display: 'flex', alignItems: 'center' }}>
                <Avatar size={50} icon={<PhoneOutlined/>}/>
                <div style={{ marginLeft: '10px' }}>
                <span>
                  Teléfono: {user?.telefono ? user?.telefono : '---'}
                </span>
                </div>
              </div>
              <Divider/>
              <div style={{ display: 'flex', alignItems: 'center' }}>
                <Avatar size={50} icon={<LockOutlined/>}/>
                <div style={{ marginLeft: '10px' }}>
                <span>
                  Rol: {user?.rol ? user?.rol : '---'}
                </span>
                </div>
              </div>
            </Card>
          </Col>
        </Row>
        <br/>
        <br/>
        <Row gutter={10} justify="center">
          <Col
            xs={{ span: 24 }}
            sm={{ span: 24 }}
            md={{ span: 12 }}
            lg={{ span: 12 }}
          >
            <Card>
              <Collapse items={items}/>
            </Card>
          </Col>
        </Row>
      </Form>
    </DefaultLayout>
  )
}

export default Perfil